package main

import (
	"context"
	"flag"
	"fmt"
	"fusenapi/constants"
	"fusenapi/server/websocket/consumer"
	"net/http"

	"fusenapi/utils/auth"

	"fusenapi/server/websocket/internal/config"
	"fusenapi/server/websocket/internal/handler"
	"fusenapi/server/websocket/internal/svc"

	"github.com/zeromicro/go-zero/core/conf"
	"github.com/zeromicro/go-zero/rest"
)

var configFile = flag.String("f", "etc/websocket.yaml", "the config file")

func main() {
	flag.Parse()

	var c config.Config
	conf.MustLoad(*configFile, &c)
	server := rest.MustNewServer(c.RestConf, rest.WithCustomCors(auth.FsCors, func(w http.ResponseWriter) {
	}))
	defer server.Stop()

	ctx := svc.NewServiceContext(c)
	//消费组装队列
	ctx1 := context.Background()
	ctx2, cancel := context.WithCancel(ctx1)
	defer cancel()
	go ctx.RabbitMq.Consume(ctx2, constants.RABBIT_MQ_ASSEMBLE_RENDER_DATA, &consumer.MqConsumerRenderResult{})
	handler.RegisterHandlers(server, ctx)
	fmt.Printf("Starting server at %s:%d...\n", c.Host, c.Port)
	server.Start()
}
